<!--
 * @Author: liulin liulin19981227@163.com
 * @Date: 2023-03-25 23:22:29
 * @LastEditors: Do not edit
 * @LastEditTime: 2023-04-15 15:53:03
 * @FilePath: /work_artfess/yhxt_web/src/views/basicDataManagement/SectionManagement.vue
 * @Description: /frontPlat/sectionManagement/children
-->
<template>
  <div class="fullheight">
    <div class="top">
      <div class="title">
        <h1>路段数据统计</h1>
      </div>
    </div>
    <el-button
      style="margin: 10px"
      type="primary"
      icon="el-icon-back"
      @click="handleReset"
    >
      返回
    </el-button>
    <div class="table">
      <el-table
        :data="tableData"
        style="width: 100%"
        v-loading="loading"
        @row-click="hanldeRowClick"
        @cell-click="handleCellClick"
        header-cell-class-name="cellClassName"
        row-class-name="rowClassName"
      >
        <el-table-column
          align="center"
          prop="name"
          label="名称"
          column-key="sectionManagement"
        >
          <template v-slot="{row}">
            <i class="el-icon-arrow-down" style="margin-right: 10px"></i>
            {{ row.name }}
          </template>
        </el-table-column>
        <el-table-column align="center" prop="roadCount" label="路段数量">
          <template v-slot="{row}">
            {{ utils.thousandBit(row.roadCount) }}
          </template>
        </el-table-column>
        <el-table-column align="center" prop="roadLength" label="路段长度">
          <template v-slot="{row}">
            {{ parseFloat(utils.thousandBit(row.roadLength)).toFixed(2) }}
          </template>
        </el-table-column>
      </el-table>
      <div class="bottom">
        <span class="item">总数</span>
        <span class="item">{{ total.roadCount || 0 }}</span>
        <span class="item">{{ total.roadLengthCount || 0 }}</span>
      </div>
    </div>
  </div>
</template>

<script>
import utils from '@/utils' // thousandBit格式化千分位
const BigNumber = require('bignumber.js')
export default {
  name: 'structureArchivesManagement',
  data() {
    return {
      tableData: [],
      data: [],
      loading: false,
      pathName: '',
      type: '',
      total: {},
      utils: utils,
    }
  },
  created() {
    this.loadData()
  },
  watch: {
    tableData(newVal) {
      this.total.roadCount = this.calculation('roadCount', newVal)
      this.total.roadLengthCount = parseFloat(
        this.calculation('roadLength', newVal)
      ).toFixed(2)
    },
  },
  methods: {
    calculation(key, arr) {
      let total = new BigNumber(0)
      if (!key || arr.length === 0) return 0
      arr.forEach((item) => {
        if (item[key]) {
          total = total.plus(item[key])
        } else {
          total = total.plus(0)
        }
      })
      return total
    },
    handleReset() {
      let length = this.data.length - 1
      if (length === 0) return
      this.tableData = this.data[this.data.length - 2]
      this.data.splice(length, 1)
    },
    hanldeRowClick(row) {
      if (row.chirldren.length == 0) {
        return this.$router.push({
          name: 'builderChildren',
          params: {
            value: row,
          },
        })
      }
      this.tableData = row.chirldren
      this.data.push(row.chirldren)
    },
    handleCellClick(row, column) {
      if (
        column.columnKey == '1' ||
        column.columnKey == '3' ||
        column.columnKey == '4'
      ) {
        this.type = column.columnKey
      }
    },
    loadData() {
      this.loading = true
      this.$http
        .post('${yhxt}/road/roadmanage/v1/getRoadCountVo')
        .then((res) => {
          this.tableData = (res && res.status == 200 && res.data) || []
          this.data = []
          this.data.push(this.tableData)
          this.loading = false
        })
        .catch(() => {
          this.loading = false
        })
    },
  },
}
</script>

<style lang="scss" scoped>
/deep/ .rowClassName:hover {
  cursor: pointer;
}
/deep/ .rowClassName .cell {
  font-size: 20px;
}
/deep/ .cellClassName .cell {
  font-size: 22px;
  font-weight: bold;
}
/deep/ .el-table tr {
  height: 60px;
}
.table {
  width: 100%;
  height: calc(100% - 110px);
  overflow: auto;
}
.top {
  width: 100%;
  height: 80px;
  display: flex;
  justify-content: center;
  align-items: center;
  .title {
    width: 95%;
    height: 50px;
    padding: 5px 10px;
    background: url('../../assets/images/标题_.png') no-repeat;
    background-size: 100% 100%;
    position: relative;
    h1 {
      position: absolute;
      top: 0;
      left: 30px;
      margin: 0;
      font-size: 40px;
      font-weight: bold;
    }
  }
}
.bottom {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 50px;
  background-color: #103c5d;
  margin-top: 10px;
  .item {
    flex: 1;
    text-align: center;
    margin-left: 10px;
    font-size: 16px;
  }
}
.charts {
  height: 450px;
  width: 100%;
  display: flex;
  margin-top: 60px;

  .column,
  .pie {
    height: 100%;
    flex: 1;
    padding: 0 20px;
  }
  .charts_top {
    display: flex;
    position: relative;
    height: 35px;
    margin-left: 30px;
    align-items: flex-end;
    background-image: linear-gradient(to right, #336da2, #1c3c60);
    p {
      position: absolute;
      left: -18px;
      top: -14px;
      width: 30px;
      height: 30px;
      display: flex;
      justify-content: center;
      align-items: center;
      border: 1px solid #6184ac;
      background-color: #304e7b;
      transform: rotate(45deg);
      border-radius: 5px;
      i {
        font-size: 25px;
        color: #91f5f3;
        transform: rotate(-45deg);
      }
    }
    h1 {
      margin-left: 25px;
      font-size: 24px;
      margin-bottom: 0px;
      font-weight: bold;
    }
  }
}
</style>
